TopModel class
A Model registered at the app root via TopProvider.
TopModel instances can be accessed from anywhere in the app using top() or MoReadContext.read().
Mix in EventModel to support event-driven local refresh:
class AppModel extends TopModel with EventModel<AppEvent> {}
Check isReady to verify a TopProvider is mounted before calling top().
- Inheritance
-
- Object
- Disposable
- Model
- TopModel
- Implementers
Constructors
- TopModel()
Properties
- disposed → bool
-
Whether this model has been disposed.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Release resources held by this object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
refresh<
T extends Model> ([VoidCallback? fn]) → void -
Update state and notify listeners to trigger a UI rebuild.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
shouldRefresh(
) → bool -
Return whether a refresh call should notify listeners.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isReady → bool
-
Whether a TopProvider is currently mounted in the widget tree.
no setter