ValueModel<T> class

A simple Model wrapping a single value.

Used internally by NoMoWidget for lightweight state without defining a custom model class.

Inheritance

Constructors

ValueModel({required T value})

Properties

disposed bool
Whether this model has been disposed.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Release resources held by this object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
refresh<T extends Model>([VoidCallback? fn]) → void
Update state and notify listeners to trigger a UI rebuild.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
shouldRefresh() bool
Return whether a refresh call should notify listeners.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited